--- title: Process keywords: fastai sidebar: home_sidebar nb_path: "nbs/02_engine.ipynb" ---
{% raw %}
{% endraw %} {% raw %}

    %load_ext autoreload
    %autoreload 2

{% endraw %} {% raw %}

    from __future__ import annotations
    from dataclasses import dataclass
    from typing import Callable

    @dataclass
    class Process:
        queries: list[Callable] # [] -> list[record]
        filter: Callable # list[record] -> list[record]
        steps: list[Callable] # list[tuple[record, bytes]] -> list[Any]

{% endraw %}

## Simple test process

In practice we'd use a something like parsel, beautifulsoup or selectolax. However for a simple demo this has no external dependencies.

{% raw %}

    from html.parser import HTMLParser

    class SkeptricHTMLParser(HTMLParser):
        def __init__(self):
            super().__init__()
            self.extract = {}
            self.field = None

        def handle_starttag(self, tag, attrs):
            if dict(attrs).get('class') == 'post-full-title':
                self.field = 'title'
            if dict(attrs).get('class') == 'byline-meta-date':
                self.field = 'date'

        def handle_endtag(self, tag):
            self.field = None

        def handle_data(self, data):
            if self.field is not None:
                self.extract[self.field] = data

    def skeptric_filter(records):
        return [r for r in records if r.mime == 'text/html' and r.status == 200]

    def skeptric_extract(content, metadata):
        parser = SkeptricHTMLParser()
        html = content.decode('utf-8')
        parser.feed(html)
        data = parser.extract
        data['url'] = metadata.url
        data['timestamp'] = metadata.timestamp
        return data

    def skeptric_verify_extract(content, metadata):
        if not content.get('title'):
            raise ValueError('Missing title')
        if not content.get('date'):
            raise ValueError('Missing date')
        return content

    test_data = '../resources/test/skeptric.warc.gz'

{% endraw %} {% raw %}

    from webrefine.query import WarcFileQuery

    skeptric_extract = Process(queries=[WarcFileQuery(test_data)],
                         filter=skeptric_filter,
                         steps=[skeptric_extract, skeptric_verify_extract])

{% endraw %} {% raw %}

    def run(proc: Process):
        records = [r for query in proc.queries for r in query.query()]
        filtered_records = proc.filter(records)

        data = [record.content for record in filtered_records]

        results = []
        errors = []
        for record, content in zip(filtered_records, data):
            print(record)
            for step in proc.steps:
                try:
                    content = step(content, record)
                except Exception as e:
                    errors.append((record, e, step.__name__))
            results.append(content)
        return results, errors

{% endraw %} {% raw %}

    results, errors = run(skeptric_extract)

{% endraw %} {% raw %}

    errors

    []

{% endraw %} {% raw %}

    results

    []

{% endraw %} {% raw %}

    errors[-1][0].preview('../data/test.html')

../data/test.html
{% endraw %} {% raw %}

    errors[-1][0].preview('../data/test.html')

    ---------------------------------------------------------------------------
    AttributeError                            Traceback (most recent call last)
    /tmp/ipykernel_1961/1913861792.py in <module>
    ----> 1 errors[-1][0].preview('../data/test.html')

    AttributeError: 'WarcFileRecord' object has no attribute 'preview'

{% endraw %} {% raw %}

    results

    [{'title': "Pagination in Internet Archive's Wayback Machine with CDX",
      'date': '23 November 2021',
      'url': 'https://skeptric.com/pagination-wayback-cdx/',
      'timestamp': datetime.datetime(2021, 11, 26, 11, 28, 34)},
     {'url': 'https://skeptric.com/robots.txt',
      'timestamp': datetime.datetime(2021, 11, 26, 11, 28, 34)},
     {'url': 'https://skeptric.com/style.main.min.5ea2f07be7e07e221a7112a3095b89d049b96c48b831f16f1015bf2d95d914e5.css',
      'timestamp': datetime.datetime(2021, 11, 26, 11, 28, 35)},
     {'url': 'https://skeptric.com/',
      'timestamp': datetime.datetime(2021, 11, 26, 11, 28, 36)},
     {'title': 'About Skeptric',
      'date': '18 October 2021',
      'url': 'https://skeptric.com/about/',
      'timestamp': datetime.datetime(2021, 11, 26, 11, 28, 37)},
     {'url': 'https://skeptric.com/tags/data',
      'timestamp': datetime.datetime(2021, 11, 26, 11, 28, 37)},
     {'url': 'https://skeptric.com/tags/data/',
      'timestamp': datetime.datetime(2021, 11, 26, 11, 28, 38)},
     b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x02\x00\x00\x00\x01\xa8\x08\x02\x00\x00\x00\xbf\xbd\xca\xb3\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x04gAMA\x00\x00\xb1\x8f\x0b\xfca\x05\x00\x00\x00\tpHYs\x00\x00\x0e\xc3\x00\x00\x0e\xc3\x01\xc7o\xa8d\x00\x00/\x06IDATx^\xed\xdd;\x8f$\xc9v\xd8\xf1\xfa r\xb8\x8e\xec\xb1\x1a\xf3\x01h\xadC\x87h\xf9\x05\xb4O\xb7\xad\x05\xe5Hh\xa3\x8d\xa5$\x08C\x8b\xce\x00K\xa7\xad&0 \x01\xe1\x9a"\xb0K\xa0\xc7!\x86\xd6@\xc6\\\x87\x17\r\x81X\xdc\x8bK\x8d\xe2\xc4\xf3\xc4+\x1f5\xf5\x8e\xff\x0f\x8d\x9d\xcc\xc8xeTF\x9c\xcc\xea\xea\xda\xcdW\x00\xc0\x90\x08\x00\x000(\x02\x00\x00\x0c\xca\x07\x80/_\xbe\xbc\xbc\xbc\xfc\x02\x00\x18\x86\x0f\x00f\xf5\x7f}}\xfd\x15\x000\x0c\x1f\x00L(\xf0\t\x00\x801\x10\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\x13\x01\xe0\x0f\xbf\xf9\xee\xebO\xdf}}\xfe\xab\xdf\xfb\x04\xaf\x97>\xe5\xe3\xc3\xcd\xcd\xc3G\xbf\x03\x008\x03\xdd\x00\xf0/\x7f\xf1\xf57\x7fg\xfe\xfd\xfd/\xdf\xff\xfb\xbf\xb8$\xab\x97n<m\xb7O~\x13\x00p\xee\xf6\x15\x00\x9e\xb6\x9bL\n\x05\xe1\x88z\x02\xb0I7\xdb\xed\x8d\xf9g\xfbd\x9e\x0e\xe4x,\xa1\xaa\xe2\xa9\x01\x00\x0ef\xc1[@\xdf\xff?\xf3\xdf\x9f\xbe\x8b\xcb}/}\xf2\t\xe0i\x9b/\xe6\xb2\xcaKnY\xfdm\xa9P8\xcbhr\x11\x03\x00\xe00z\x01`\xf5\xeao\xac\x0b\x00n\xdf\x04\x80\xb0\xf0\xfb8\xe0o\xfe\xa3~\x9d\x00\x80o0\xf1\x04`\xfc\xe17\xdf\xff\xf1\xb7\xe6\xdf\xbf\xfb\xf7\x9f\xfe\xe2\x0f.\xc9j\xa7\xef#\x00||\xd8r\xcb\x0f\x00\xc7\xb0\xdf\x00\x10\x16\xf9\xf8\xc6N\xb44\x00HB\x9e\x13\x00p\x10\xd3\x01\xe0\xd7\xdf\xfeU\xe3\xad\x1e\xa3\x9d.\xeb~\xf1\xbeMJ\n\xcc\xa1\xf0>\x8f\xd9\xb4\xc7e\xc5\xb7i!\x16\xb8\xc3N\xac\n\x00\xb0O3\x01\x00\x00p\xad\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\xda\x01\xe0\x9f\x01\x1c\x8c\x9ff\xc0\xa9\x11\x00\x80c\xf3\xd3\x0c85\x02\x00pl~\x9a\x01\xa7v\x96\x01\xe0\xdd\xad\xff#\xb0\xdbw>\x05+|\xb8\x7f\xb3\xd9\xbc\xb9\xff\xe0w\xaf\xdf\xbb\xdb\xf38\xdb\x7f\xb8\xdd\xfc\x97\x8d\xfc\xfc\x8d\xben\x1b\xbd\xf3\xd3\x0c8\xb5\xf3\x0b\x00f\xf9\n\x13\xc6l^b\x08xw{\xf2^\x7f\xb8\xbf\xbd\x9e\x0003\x9egr\x95\xfc\xe3\xfd\x9b\xff\x16\xae\xdb\xa77\xb7\xff`\xb7\xac\xba\x83~\x9a\x01\xa7\xd6\x0e\x00\xf6\x16\xfc\xcd\xfd;\xb9\x95\xb4\xd4=\x8c\xbd\xbft\xf2;\x9bx\xc0\x17\x0cG\xe3\xfd|Y\xa0)_\xba\xe6\xd7RW\xbbT\xec\xdb\x89\x05\xba\xed\xc6\x03\xb7\xefl\x9f\xcdQ\x9b\xe4J\xba\xd3P%\xe6\xeb\xd9\xdc\xde\x86\xbb<\x95\xd9:\xc4\xd2\x94^\x817\xf7\xf7\xe9\xf6Ru\xc7\x9c\x97\x1fE\x9f(\xdd\xf0\xc5\xf2s\xa8\xb8\x02\x92I\x15UG\xac\xce8\x9cd<M\x8e\xbc\x8b\'\xban\x9fn\xef\xff\xd1oK\xd9\xc9\x87\x00?\xcd\x80S\xeb>\x01\xd8\xcb_\xcf\xac\xb0\xfd\xe1\xdd\xbbp-\x17s/lK\xd1x\xc1g\xd7\xbe927\x97\xca\x00\xb0`\xeeek\xcc\x87\xfb{\xdb\x8d^\xbbj\xd3\x14{\xf3&\xb6\xa6c\x8d\xeaD\xb7\xff\xea\x80\xb4\x9f\xe5J5M\xfa\xfc\xbf\xfeT\xbe[\xbb\xfc\xf9\xd3\x7f\xfd\'\x9f\xa1A\xda\xd2\x83\x1eO;>7\xd9,\xaa?\xb1\xd3\x92{Q\xcfl\x05\xb1\xe2\xf3\x1eO\x937;*\'\xd9\xbc*\xf7p\xddN\xbd^e\x00\x08O\x03\x96\x8c\x8c\xde\xf7\xd3\x0c8\xb5\xa9\x00PL,=O\xa2\x94\xa8\xaf\xf0\xb4\x97e\xb6\xb2Zk\xbb\x05\x00]\xc6\xea\xb5\x9bW\xa8\'f{\xc1\x9a\xe8\xbf,SAvR\x8b\x03\xc0\x0e\x1a\xa7*\xca\xe4b\xdc\xccY\x98\xb5y\xc9PZ\x974\x9e\xa6\xc2"s\xafp\xd6tJ\xd4\xfdO{\x13\xfdl\x9b\x0c\x00R\x9d.\xef\xa7\x19pj\x13\x01 _/\xfcD\xca\xefe\xf4\xec\xd2\xd9\xd3\x84\xef,X}\xa6\x015U&\xe7~\xd4h\xa4\xd7nqZjW7\xb5\xb6\xff\xbdQ\x99\xb1\xc3\x13@\xa7?er\xf9r\xc8#\x81\xb9;_\xd6\xadV#\xbdq8\xf9x\xd6\x0b~\xd6\xa1Px/\xd7\xed\xf4\x13\x80~\xdf\xbfx\x0b\xc8\xec\x13\x00p\x8e&\xdf\x02jL\x19=a$K\xbc\xac\x8b\x03q\'\x9fyK\xbc\xbbWe\xf5\xb4\xe9j\xcd\xd6^\xbb\xba\x9f&O\xeb\x99?;\xf5%\xf5\x14\x1dM\x87\xa4\x81Eg\xb0\\\xde\x9f\xd8@\xd6\x03I\x8d\x99\xd2\xab\x94%O\xb9\xa4\xf1\xcc\xb3\x16\x8d\xc9\xae;\xaa\xabO#bw\xb2\x03q\xa7\xd7\xcf\xbew\xf7O\xa1l\xfeK\xe0\xba2?\xcd\x80S\x9b|\x02\xb873\xc5\xcb\xa7\x8f\xe33\x84\xb9\xa4\x0e\xdc\xde\xea\x15$\x1d\x10\xc5\x04nH\xf9\xe7\xf3\xca\x92\xa0\xe9\x12\x9dvU\xf2\xad9\x83\xfa\xc4\x8a_\x06\xb6\xeb\xe9Tn\xa5N\xcd\x9f\xc0\x0et\xd3\xa9\x01=\x12\xe6\xbc\xdc\t\x84\xac\x92-d\x98\\\xd7.o<M\xc1\xbc\x93\xa7\xbbn\xff\xc6~\x06\xb4\xfc\x18\xa8\xa1\xa3\x8c\xf0\xd3\x0c8\xb5\xc5o\x01\xad\xf2M\x85\x8fi\xd9;\x12X\xea\x14\xe3i\xc2\x83Z\x9c\xcf\xf0\xba\xcd;(\xfc4\x03N\xad\x1d\x00\xf4\xdd\xd2\xf2\t\xb1[\xa9SI\xb7\x95\x17\x12\xac\xce\xdc\t\xc73\xae\xdbgy\xdd6\xa2\x8a\x9ff\xc0\xa9u\x9f\x00\x00\x1c\x88\x9ff\xc0\xa9\x9d$\x00\xe4o\xae&\xbd\xb7Y\xd7\xe6\xc74\xc6\xf3\xc4\xfc4\x03N\xad\x1d\x00\x00\x00W\x8f\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x1f\x00^^^^__}\x1a\x00`\x00>\x00|\xf9\xf2\xc5\xc4\x00\xf3\x1c\x00\x00\x18\x84\x0f\x00\x00\x80\xd1\x10\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A5\x02\xc0\xa7\xc7\xb7\xfe\xfb\xe1\xdf>~z\xbe\xbb{\x96\xc4\xe7;\x9f\xe6\x98#:\xa7\xec\xc6\x1c\xee\xd8NL\x85\xdfP\xfa\x1a4\xc7yZz\xbd\xdcK\x15\xf4\xd2G\xd3\x1d\x87\xce\x15\xeb\xf2\x8fr\x1d\x86A\xf8\xf6\xf3]{\xbdu\xf2\xa7\xe4\xc1\x97\x82\xe3(\x03\x80\x0c\x7f|=\xec\xc5\x11\xf6\xcc\x91\xf4B=\xdf\xf9W\xe7\xd3\xe3\x9dz\x99\xf2\xbd\x8e\x10S\xd0\x90\rN\x1c\xe5\t\xe65j\xbeBf\'\x14V\x9b\xe3\xe9\x8c\x83\xd9N\x0b\x8c\x1eg7\x9e\x8b.\xe4#Y;_v\x99_K\xae\xb4i\xbd\xeb\xb0\xa7\x93_%g\xdb8\x90"\x00L\\<\xf9\xcb\x1a2\xae\x0c\x00\xe65\xcd\xa4\x1a\xc3\x11u!\xda\xa4\xb7wwrGp\xf7,S\xd6n\xe8\xa3N~\xf1\xa6\x03w\xa6\xac>\xe4\xaa\xe8\x9eab\xab\x08\'(et5\x9d\xfa\xdb\xfdq\xa9\x92\xe0\x8f/h=X4\x93u\xa6|!S\x85\xa7_\x17\xdb\xb3\xee8\xbb\xc3V9\x9e\xeb\xb4\xeaI\xc3\xd3\xdb\x13;\xbf\x8e\xc6\x92q\xa8\x97\xbf\x85\x01\xc0v\xd1\xd5\xbf\xf8:Y%\xd5\xe1\xe8sV\xc7br?\xbf\x7fYE\xa3/\xed\x00\xb0\xeb8/\t\'K\xf2g\xaf]\xcd\x9e\xec\xe1\xaf\xdb\xeb\x96\x07\x80\xa9\xeb\xde\x0cp\xe3%\xcbK,\x9a7S/ky)\xc8\x8b(\xb9\xe5\xd5\xb5\xa5B\xe1,\xa3\xc9\x15\xf7\xd4\x01)\x94U\xb7\xeb\x05\xadO\xabS\x7f\xb7?\x86k\xd6\xa5|z|\\\xd4\xbc1s\xf9\x07\xaev\xabh4\xee\x86Q\xec\xeb\x8e\xb3\xd9\x88\xd5\xe8\xf3]\xadWO~\xc9\xa4s\xde\xd7\xebh\xf2\xc6\xb2\xe58\xb8zZ+\xe2\xa2\x0b\xd9Zy\x9d\xec\xa0y\x1dd\x97\x98>\xc7N\xfe\xaf\x9f\x9e\x9fS\xd7\xaa\xb1\xcb.\xdfh\xcd8\xfb\xcc\xd6\xa2\x93\x9d\xcd\xdf\xeeS\xee\xf0\xd7\xed\xb5[\x15\x00\xfc\xebe\xa8\xc1\xd5%\x16\xcd\x9b\xf6\x05\xea\x94/z\xd87\x8d\xbbB\xbe\xb0\xbc\xf0\xb9X\xa7\xeeg\xbf\xa1Y\xba\x97\xd9i5\xeb\x9f\xe8\xcf\xc2Q\xa9L\r\x93\xa2#\xca\xf3c1x\xbe/o\x1f\x1fg*\xeb\x8d\xb3\xb1\xa7\xf1\xec\xd7\xa3\x9b\x9a\x1b\xe7\x9d\xcc\x8d\x83i\xa9\\\x1f\x96\xbfd\xeb\xae\x93]\xb4.\x842M\xb7\xdc\xcaod\x97h\x99c\xc9b;m\xe2:l\x9a\xc9oz\xbb\xa4GG\xb8n\xaf\\\xf5\x16Pw\xd8\xe3\x18g\xf2\x99\xb2\xe8:\xea\\\xa0VYA\xef\x05^6AM\xa9\x05\xfdi\xd3\xbd\xec\xb5\x96\xea\x9f\xec\xcf\xb2\xce\x16\xa6FI\xc9\xea\xee64\xdb\x83\x89\x89\xa4|\xcbxjE=\xa1w\xddS\xdeW\xbb\xb1\xa5R\x95>;`\xd1\xba\xebd\x17\xada)\xd3t\xcb\xad\xfcy\x0f\xea\x1c\x8b&\xee\x94\xec\xd4\x17\x8c\xdeT~\tU\x0b\xbbs\xdc\xeb\xf6\x1a5~\t\xac\xc6\xca\xec\xc5\xe8\x19\xc78g^\xad\x98\xac\xb7\xfb\xd2\xc5\xa6\xabw\xca\x0b\xb1\xfb\x02\xe7\xfdL\xb2\n\xca.K{Ko\x07RE\xd9\xf5\xd8\xab\xbf\xd7\x1f\xb1`>Tz\x17r\xd5\x7f\x9d\xb1\xd3P9\x0c\r\xddq\x9e\x1a\xcfVwz&_\x17\xdbZ\xde\xf9\xc9\xfck\x1aVt5\xfaR\x95\xea\x8a\xca\x96\xbfd\xa9\xa2E\xd7\x89X\xd9\xfdT\x95\xeahV\x7f\xde\xddV~\x9d]\xfaY6\x9eW\x17\xac\xe9\xe8\xd4u\xd8\xaa\xa7\x93\xbf\x18\xc4\xb9\xb6C\xbfM\x0b.\xeb\x92\xeb\x16J\x19\x00\x0cy\r\x828n*\xb1\xbcT\xdc\xcb\xdb:\xd2\x91\n\xc4\xeaSR`\x0e\x856\xcd\xa6=.\xd5\xdb4WL\xf73V\xd5L\x0c\\+EbO\xac\xe9\xed\xe3sh}\xb2\xfe\xd6\xa1\xf2\xbc\x16\xb6m\xeaj\xe5l\xf6_7\xa1\x0eu\x92[B\xc7M6[J\x8f\xf3\xc4\xf9\xc6\xbcKL\xd4#\xa4\xae,q2\xbf;\xb7\xaa\x92\xa6\xee8\xa8\x03\xea$tv1{~\xa9\xa3K\xaf\x13\xdb\xc4\xd2q\x13\xa9O\xba\x9e\xac\x85\xce\x99\xa9d\xdd\xcfG\xd9\xb6\xc7\xca\xd3\xcdkrG\xb3\xba\xfbtUE\x91f=\xcd\xfc\xf9\xb0\xcd\xb4\x1d2\x9bL\xb62\x19S\x9bf\x12\xf2\x8a&\xab\x19[#\x00\x00K\x989\xb6f\x19\x9b\xb4\xfc\x8e\xfb\xdc\xcc\xdf\xa5\x96\xf69n\xc0\xb7!\x00`7f\x1d\xdb\xc3\x8d\xd5\xc4}\xe3eX\x1d\x00\xf63n\xc0^\x10\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`PY\x00\x08\x9f\xc8\xb0\x9fR\x8b\x9f\xcf\x98\xfe\xccB\xf8\xc0m\xf9\xc9\xb6^\xfaNL_N\xf4\xc99;\n\xf9\x08\xa4\x0f\xae\x14#\x13N\x99O\xf9\x01\xb8\x08\xf9\x13@\xf5q\xec\xf6_\x08\xd6z\xf9\x96\x96\x17\xeb?Q}p\xf6#{y\xbfT,\xd2aI\xa2B\xdcYs\xd6\x00p*\xc5[@~\xb13\x0b\x9f[\xc2\xd2\xe2\x97\xee{[7\xb8\xdf\x1a\x00\xe2\xcd\xb3\x97\x96\xdc\xc6\x93\x84MZ\xff5\xd1\xe1\x1c\xf4r>%\xac\xefy\x00\xc8\xf6:\x7f\xbf4s\xd6\xd3\xfdW\'\xc0\xd7\xd8\x028\xa4*\x00\xc8\x8ac\xd65\xc3m\x84\x05h\x97\xaf\x93\xed\xa7\xb7\xe4\x0bm\xae\xacG\x16I\xc9-\xab\xa7-\x15\ng\x19M\xae\xac\xd8\x9a\x00\x90N2\xefW\x08\x0b"\xf4"\xf0ky+B\x16\xba\xfd7\x1b\xb1\xb4\x1c\x9c\xaf\n\x00vT\x04\x00\xbb\xe2\xdb\xff\xd8\x85H\xdf\xe1\xca\x9a\x15\xe9eO\xf4\x16\xfa^z\xcb\xba\x00\xe0\xf6\xcd\x1a\xe9\n\xf9\xc2Y\'\xad~\x9d\x93\xc2Z\xeee\xad\xc7F\x96\x7f\xbdp\xa9\xd7\x7fC\xb7\xbcc\xe7\x01`\x89"\x00\xc8B\xf4\xe8\x16%Y\xa3\xe2\xfa\x96\xafi\xf5R\xdd[\xe8{\xe9-\xfb\x08\x00:b\xed\xcbD\xbfz\xcd\xcdv\xa3\xd7\xff\\>\xea\x00\xb0_u\x00x\xfb6\xaeIf\xcb\xaf?z\x01.\xdf\xf8\x10\xfa\xb8\xd6KoIy\xe5&8o\xa1\xac\'\xecW\x0b\xe8\xe4\x9a)\xf5\xae\xbf\xad\xee\x06\x80\xd8\xb8a\x06%n\xd7\xdd\xaft\xfb\x9f\x9d\xa8n\x00\x00\xf6\xad\x0c\x00z\xf12\x8bZZ\x8d\xd2\x9b+K\xbeN\xb6\x97>)\x15\x8a\x99\x9b\xf5\x84\xae\x98M{\\:i\xd3\\\xb1\xd4S\xa1\xdbu\xb5\xe9\x94\x19\xb1\xf94\x0e\xbaGYM\xea\x80Z\xc3[\xa6\xfa\xdf\xef<\x00\xecY\x19\x00\x00\x00\x83 \x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x15\x00>=\xbe\xdd\xd4\xde>\xfe\xbdI\xbf{\xf6\x99Vx\xbe\xb3\x15\xbc\xf9\xb37;\x15\xc7q\x98\x97\xfd\xed\xe3\'\xf7\xea\xcb\xebd6x\xb9\x801\xb4\x9e\x00d-Pk@\xb1\xbb\x94Y\xffeaYa\xc7\x86\xa0\xac\x1eC\xf32\xd9\xfcR\xd0\x97\x0cI\x00\xae\xdc\xc1\x02\xc0\x0e\xa5vk\x08\xda\xca14\xd9}\x94\x96\x82!`\xaf\x8f\xdd\x00.\xd1\xe2\x00\xe0\xdf\xd0\xd1\x07BR\xbd\xe2H\x11\xef\xee\xafCm\xb2\xd8\xdc\xdd\xc9\x01\xbb\x1bK\xfb\xc5&\xee\xd7k\x8f\x94||\xacZK5\xa8\xc4\xd8\xf4\xdd\xa3:\x8d~W\x9d\xb23N\xb3T\x9dh\x07HZ\x0b\xc9\xa9\x0f!K\xbb~m\x87j\xcd~1,\xb1\x12iEvbe\xbe\xba\xb4k\xd9\x1a\\\x7f\xe4p\xec\x9b)\xda\xeb\'\x80\xeb\xb10\x00\x84\xa5$-*)S\xb6tD\xf1x\xb6\xe1\x8bdKL\xdcLU\x16lI\x7fHz`\xb3\xa7\xae\xa44\x95\xa8\xca\xa4ze\xab\xeej\xea\x81\xdel\x96\xea&\x86m\xe9\x80\xdfN9\x9a\xf5k\xbbUk3\xf8r\x92ARSM\xba\xd6r\xc7\xcb\xd2t\xcfZ\x99\x01\\\x9d\x85\x01 ,\r\xf1Pw\xed\x08\xea\x9c\xba\x1e\xbb`\xa96\xac\xacN-;\xd0\xca\x15:\x90u$4\x91\x15huu\xbe3\xa1T\xbb*\x9d\xda\xdcn\xd5\xaf\xedXmV\xcc\xef\xb4\xd2\x8a\xcd$\xeb\x97\xd9I\x19b\'\x00\\\xb1\x95\xbf\x03\x88\xdb\xb2\xa1U\xcbE\x963\xdf\xf0d\xf9q|j\x99!\xca\x0fd+d$I\x92\x90:\x12Je\xd9\x8c\xe6\xca\xd6\xec\x8cfK\xb5\xab\n\r\x85b\xad\xed\xaa~m\xc7jub\x18\x96<Mgm\x9cv\x1cI\xbfSV\xe6w\x00\\\xa9o\t\x00*O\xad\xce\xd9+"k\xe3t\x9d\xd9\x01\xbf#\xff\xc45*\xacW\xe5\x8afKu\xabm\x99\xeeL\xbb*\x9d\xda\xdb\x0eb\xfd\xda\x8e\xd5f\xc5\xfcN\x96f\x98\xf6\\jk=/+H\x05\xb3\x81\x04p\xa5v\r\x00:\xb5\xc8\xef\xc4\xc4z\xc3o\x87\x15&[s\x9b\xcb\x8e\x1c\x08GBn\xb5\x92\xca\xa6?\x9cRm\x99T\xaf\xcf\xaa6\x13\xddn^AUj.\xb1\xb9-\xff\xd6\xf5k\xaaT\xdalU\x95m\xcbF9,\x92\x16\xda\xb2\xcc\x01\xf9Mr\x96\x16\xe8Z3\xdd\x03\x00\xae\xc9\xce\x01\xc0\x90E\xc7j\xad.1g\xbd\xe1\xc4\xd2\xa9\xb8\xe40T&\xc7\x96\xbc\xf3\xf9Cn\x9f\xd9\xa6<\xa7\xaac\xb2\x14\x885Ov\xd5ht\xc6h\x96\xaa\x13\xf5\x89u\xb6\xdb\xf5k;Tk7:\xc3\x122\xfb\x8a\xd3nFUk\xcb\x85l\xa6L\xaf\x9f\x00\xaeG+\x00\x9c\x1d\xb5N\xadp\xf5\xab\xd8\xb2a\x99\xcce\x0e6\xc6\x88\xf5\x1f\x18\xc3u\x05\x00\xc9\x18\x96.\xb9\xf3]\x1f5.\xc9\xa2a\x99\xcbd\x86\xa9<\xdcH\x02p\x8d\xae\xed\t@\xb2zW\x7f\x13;7,~,fF\xce\xe4\xcaF\xaa\xdc\x07p\xb5."\x00\x00\x00\xf6\x8f\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0|\x00\xf8\xf2\xe5\xcb\xcb\xcb\xcb/\x00\x80a\xf8\x00`V\xff\xd7\xd7\xd7_\x01\x00\xc3\xf0\x01\xc0\x84\x02\x9f\x00\x00\x18\x03\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\xed\x00\xf0\xcf\x80\xe2/\x0b\x00\xd7\x85\x00\x80y\xfe\xb2\x00p]\xce2\x00\xbc\xbb\xdd8\xb7\xef|\nN\xca_\x16\x00\xae\xcb\xf9\x05\x80\x0f\xf7o\xde\xdc\x7f\x08\x9b\x97\x18\x02\xde\xdd\x9e\xa6\xd7\xfbj\xb7\xae\xc7_\x16\x00\xaeK;\x00\xd8[\xf07\xf7\xef\xee\xdf\xb8;q\xb3\xed\x96d\xc3\xac\xca>Q\xa7\x1a\xf1\x80/\x18\x8e\xc6\xfb\xf9\xb2@\xd3\x87\xfb[\x95i~Ms\xb5K\xc5\xbe\x9dX\xa0\xdbn<p\xfb\xce\xf6\xd9\x1c\xb5I\xae\xa4;\rUb\xbe\x9e\xcd\xed\xed\xad?\xa42[K\x96\xe44\xa2o\xee\xefCE\x86\xaa+T\xe3\xfay\x1f\x0b\xb4N\xd6R\xed\xaaC\xb1\xee\x95\xf5\xf8\xcb\x02\xc0u\xe9>\x01\xb8%B\xad\x0ba\xfb\xc3\xbbwj\x85j\xe5\x90\xa2j\xa9Q\xab\xa69\xa2\xf6\x9a\xca\x000\x97_\xe85\xfb\xc3\xfd\xbd\xedF\xaf]\xb5i\x8a\xbdy\x13[\xd3\xb1Fu\xa2\xdb\x7fu@\xda\xcfr\xa5\x9afIY=\x88\xa1\xa2l\xa8\xa4\xa7\xa9\xdd\xf4\xba\xe4\xc3\xd3lw\xa2\xff\xcb\xeb\xf1\x97\x05\x80\xeb2\x15\x00\xb2e \xad\n\xb2rD\xbd%$\xece\x99\xadrq)\xec\x16\x00t\x19\xab\xd7n^a\xbe\xb0\xa6\x9e\xa5\n\'\xfa/Kw\x90\x9d\xd4\x9a\x00\xd0\xe8\xbaU\xd6\xa1{\xd4\xea\xa7h\xb5\xdb\xef\xff\x9az\xfce\x01\xe0\xbaL\x04\x80|\xe9\xf5\xab\x82^2\xf5RQ.\xacaA\xe9-p]\xa6\x01\xb5\xfc\xb4\xd6\xb4Z\xa3\x91^\xbb\xc5i\xa9\xdd\xf6\x82\xb8\xac\xff\xbdQ\x99\xd7\xefg^G\xca\xd7\xee\xa7h\xb5\xdb\xef\xff\x9az\xfce\x01\xe0\xbaL\xbe\x05\xd4X\xd4\xf4\x02*Y\xe2RQ\x1c\x88;\xf9\xda\xb8\xc4\xbb{U\xb6^\xd2\x1aZ\xab\\\xaf]\xddO\x93G\xbf%\x126\xb3S_RO\xd1\xd1tH\x1a\xd0g \xfb\xc5\xe3B^\x7f*\x90\xd5o\xd2\xe3\x19N-\xdc\x8dv\xf3\xfa\x955\xf5\xf8\xcb\x02\xc0u\x99|\x02\xb8O\xef\x1f\xa4E$\xbd\xa9\xe03\x84uD\x1d\xb8\xbd\xcd\x17\x14\x9fn\xa5e\xa7\'\xe5\x9f\xcf+K\x94\xa6Kt\xdaU\xc9\xb7\xe6\x0c\xea\x13+~\x89\xdd\xae\xa7S\xb9\x95:U\x9c\x80;P$fU\xa9cY\x0bE\xab\xb2\x1bZI/M\xa7\xddFWW\xd6\xe3/\x0b\x00\xd7e\xf1[@\xab|S\xe1cj=;\xa0\xe2/\x0b\x00\xd7\xa5\x1d\x00\xd2=\xe3\x9a\x85|\xb7R\xa7\x92ns/$X\x9d\x90\xbf,\x00\\\x97\xee\x13\x00\x10\xf9\xcb\x02\xc0u9I\x00\xc8\xdf\x94N\xb2w\xae\x95\xb5\xf9\xb1g\xfe\xb2\x00p]x\x02\xc0<\x7fY\x00\xb8.\xed\x00\x00\x00\xb8z\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\xf9\x00\xf0\xf2\xf2\xf2\xfa\xfa\xea\xd3\x00\x00\x03\xf0\x01\xe0\xcb\x97/&\x06\x98\xe7\x00\x00\xc0 |\x00\x00\x00\x8c\x86\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000\xa8S\x05\x80O\x8fo\xdf>~\xf2;\x00\x80\xe3k\x07\x00\xb3<o6\x13\x0bt\xff\xf8\xf3\x9d\xfd_\xb5\xe8c6s\x9d\xfd\xf9n}\x04\x98\xeb\x17\x00`\xb1\xee\x13\xc0\xf4\xfa,\xeb|\xf3x\xafX#\xdd\xac\xe6w\xcf~{\xa9n\xbb\x00\x80\x95\xa6\x03\x80\xbf\x9fo\xdd\xbeo6\xcd\xd5{E\x00h%\xda\x06\xef\x1e\xdd3\x83l\x16mt\xdb\x05\x00\xac4\x11\x00\xcc\xfa\x1b\xd7g\xb3\x97\xad\xbb\xe6\xee}\xc5Bo\xb4\xd3[\x0f\x01z\x8d\xafJu\xdb\x05\x00\xac4\x15\x00\xb2\xb5\xf9\xf9n\xd1\x9d\xf7\xba\x00\xd0J\xd7\r}z\xbcc\xb9\x07\x80\xc3X\xfc;\x80\x03\x05\x80\xfa!\x80\x00\x00\x00G1\xf9\x16PZ\xb3\xcb\xe7\x81\xae\xd5\x01\xa0:D\x00\x00\x80\xa3h\x07\x00s[.\xcb\xff\xa3\xfc\x1e\xc0\xea\xae\xde\xa5\x1d\x02\x80~\x08\x90\xb0#d\xdfv\xc2X\xdc6\x00`\x85\xee\x13\xc0\x8ev\t\x00sG\x01\x00\x07\xb0\xff\x00P\xdd\xb5\xfb;y\x96x\x008+\xfb\x0e\x00\x00\x80\x0bA\x00\x00\x80A\x11\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\x04\x00\x00\x18T\x1e\x00>=\xbe\xdd\xdc=\xfb\x9d\xa5\x9e\xef6o\x1f?\xf9\x9d3`\xfa#\xde\xfc\xd9\x9b\xa5\xe7rng\x00\x00\xc7\xb0k\x00P9\x97.\x9f;E\x17\xb1\xae\xe0\x0e\xab\xf9\x15\x05\x80\x9d\x07\x19\xc0x\xf6\x10\x00\xcc\xe6\xa22;\xafM\xab\n\xee\xd2\n\x01\x00\xc0\x88\x16\x06\x00\xb3D:\xeeh\xdc\xcd\xd7\xcd\x98\xdcXO\xf3"\xa6\xa1\xb7wwo\xcd\xee\xdd_\x9a\x03\xaa\xcd\xaa\x0bU[\x92#O\x89\xd2\xa1\xcd\xdd_\x87\x8al\x8d\x8f\xe1H*\x93\xce\xe9\xae\x1d\x00\xd2\xe9d=\xf4z\xd5\xd6\xdd\xeb\xe5\xcc\xa4\xde\x84\x96\xf2b&9\xd6\xec\xb3\x98\xfd\xb7\x8f\x8f\xba\\6V\xb2\xa3\xbam\xab+\xce\xa2\xae\xc1j\x9exj]\xfa\x14\x92\xebn\x03\xb8\x18K\x02@J\x95-\xb7\x805r\x9a\xb5 ,nj3\xd1Ed;\xecdU5\xea\xcd\xd3\xd4\xb2\xa66\x93\x989\xdb\x08\xddIE\xd2\x96>\xae\x14\rU\x19\xe6\xaaM\x9b\xed\x9cZ\xec\xab\xdd\xf2Y\xcbb~;\xe5\xb0\x19T\xbb\x92\x9aj\xd2\xb5\x96;A\xab\x06\xdd\xc5\x98\xa6\x12U\x99T\xa7l\xb9\x8c\x00.\xc7\x82\x00\x90%\x9a\x85\xc0N\xf4FN\xb5p4\xe9"\xd9\x82\xa1\x0e4\xaa\xad\x0b\xc6\x0c\xa13Z\xcc\x90m\x84l11+\xda\xaa\'\xd3k\xa8\xaa6n\x88P\xaa\x99Sk\x96\xcaR\x9b\xdbY1\xbf\xd3J+6\x95^\xee(t&\x1b\x00\xb3c3f\x05\xb2\x1c\x00.\xc2\xc2\x00\xa0\xd9y\xde\xcci\x97\x06\xa7>\x96\x15\xc9\x8b\xc7=\xb3\xd1XEt\xe6l\x9d\xc9kqt]\xc5\x86\xda\x96\x7f\xb3\x15\xad\xb5xI\xa6\xa8\xca\xd0\xaa\xb6\xdd\xbdVN\xf9\xd71{i\xc7qU\xb4\x8ae\xdb:14\x9d\xa7\xe9\xac\xbd3,k0\x1b\x92\x1cI\x92$\xa4\xf2\xa1T\x96\xcdh\xb5\x00\xe0\x8c\xad}\x02\x08\x9a\x89\x91YJ\xa6\x8b\x94\xc5M\x01\xb3kR\xe7\x96\xa9\xac`\xb6\xdcz1C\xbd\xa1\xb7\xb3\xa2\xbdzb\xe2dCz[\'\xc6R\xcd\x9cZ3\xb1[,ng\xc5\xfcN\x96f\x98>\xb8\xd4\xaa\xff\xa2WCu\xe2\xd9\x00\x98\x1d[\xaal\x0b\xc0\x85Y\xf7;\x80\xb4\x99-\x13\x96N\tKDFgPU:\xb2P=N,S\xf1\x80\xaa\xba\xdbJ\xeca\xbe\x91m\xa7\xc2\x92V\x9c\x8bQ\xb4Sg\x98\xab6m\xb6sj*5m\xf6\x8a\xc5m\xd9\x08\xfd\n\x8dIZ\xd6Us\xa0;\xb0\xcd\x1a\x8a3\xf0\x87S\xaa-\x93:\xe0\xb3\xaaM\x00\x97\xa2\x0e\x00\x99\xb0n\xd8\xa5@\'\x84\xac\xd9\xa4\x8f\xb9\xf25(PE\xea\xf5\xc2\x96\xed,!y[\xa9\x93\xadVb\xcd\xf5Fc\xdb\xd5\xf2\xd8\xb8\xc1\x8f\x87%\xc3\xb3*\x16\xccU\x9b\xba\xd7\xcb\x99i\x8fp\xaf\x01\xbbm7\xee|9\xdd\x98\x91\xda\x98\x1b\xd8^\r6E\x9dxL\xce>4Uw\x1b\xc0\xc5\xc8\x03\xc0\t\xd9\xb5\xa8\xbdL\xa1m\xd9\x90M\xe5\xdam\xd0\xcd\xa2\xcfr\x0f\\\x83s\t\x00\xac\xff\xeb-\x1a\xb3\xc9L\x8bG]2\x86E_n\xfay\xa9\x80kp\x06\x01@\x16\x17\x835e\xad\xb9\xe5{~`\x17\x07\x80X\x99\xe0\xf6\x1f\xb8\x12g\xf3\x16\x10\x00\xe0\xb8\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\xca\x07\x80/_\xbe\xbc\xbc\xbc\xfc\x02\x00\x18\x86\x0f\x00f\xf5\x7f}}\xfd\x15\x000\x0c\x1f\x00L(\xf0\t\x00\x801\x10\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\x04\x00\x00\x18\xd4L\x00xz\xbf\xd9\xfc\x10~\xde?\xf9\xd43\xf5\xf1\xe1f\xb3\xb9y\xf8\xe8w\xcf\xc8\x1e{\xf6\xb4\xdd\xac\xaf\xeai\xfb\xc3\xe6\xe6\xc3\xb1\x07\xe6\xe3\x87\x9b\xa3\\3\xe7\xfb\xba\x03gn2\x00\xfc\xbc\xdd\xfc\xb0=\xfe\xaa\xff\xb4\xdd\xb9\xd1\x8f\x0f\xdb\xe3-\x04\xab\xfa\xf9\xb4\xdd\xdb\x12\xb5\xc7\xaa\x0eJ\xee\x1e\xd6\x04\x80Ky\xdd\x81\xab\xd1\x0b\x00\x1f\x1f~T\xf7\xfe\xf2\xe3&\xa7\xdcK\xba\xa7\x81\xf0pp\xf3\xf0\xd9\x96\xd0E~\xb4\xb3\xf1\xf3\xc3\x8d\xecn\xb7&\xa7Iq\xbb\xeeP\x97\xbd\xc1U\xf4\x92\x10\x8fm\x9f\xf4M_*"\xe9\xb2\x10\xb8\xbb\xe4\xed\xd6\xe4\ty\xf3\x9a*\xb6\xc4\xf6\xc1\xe5\x94M\x9dY\xf5)\xa6\xab4K\x15P\x87\xd4BmW\xedx([\xc1[\xf5\x8b~\xba-\x9e\x0egG\x0br\x1b\xee^\x94\xb8\x16\xf7^\x17\x9f\xbe\xd9\xfe\x1c_J]s\xf5\xfa\x8a\xde\xf5\x10\xd2\xe3\xcfL$P\xe7j\xe9\x86\xe3\xb1\xfd\xbf\xee\xc0\xd8vy\x02\x08S]\x0e\x85\xc7|;\xe1\xc3$\xb7\x19lA\xa9\xc1,(6EV\r\xc9fv\xa75\xef\x04\xcd\xe4\x0e\xab\xa6\x99\xd977\xfe\x8eO\xb6}\xb2lg\xab\x83\xed\x9fI\xb3\xb5\xcd\xde^\x86\x12n;V\xaa\xda\xcd[\xebT\x99\xdd\x9e\xab\xc2R}\xaa\xc9\xec\xf9\xb2\xbd\xfa\'\xdb\xb5;R\xe3\xcc9E2\xfez\t\xee\xbe.\xb2q\xf3\xe3\xd6\x05u\x1b<\xd4\x82^\xbf\xbe\x96\xdd-\xae\x87\x90\xae\x1b\x9ds\x9a\xd7\x1d\x18\xd8\xce\x01 O/s\x86\x05%\xa4\x87\xb5`\xe7\x00\x90\xad\xabi\xfa\x97\x8f\xfe1[\xd809]e\x0b\x02@\xca\x90\xaa-\x8b\xe9\x06\xdb\xfd\x94\xbbN\xcd\xe71\x07\xb2\xdc\xbep\xaf\xfe\xe9vm\xc5z@\xe6\x94kq\xf7u\xb1\x01 \xfd\xb6@\xee\xfae\xb7\xf7\xfa\xba\x9d\xfaz\xb0\xcaF\xe7\xb4\xc7\xf3\xd0\xaf;0\xb0]\x03@1\xb1\x8f\x1c\x00\xe2\xee\x1e\x17\x02\x9d!U[\x16\xcb\x17\xe2\xba\xca\xb2CQq\x02\xa1p\xaf\xfe\xe9v\xdd\xbbUu\xeb]\xe5K6\x19\x00\xd4\x0b\xb48\x00\xb4\x16\xfa^zOk<\x0f\xff\xba\x03\x03\xdbS\x000\xf3\xac\xfb\x16\x90lT\x0b\xcd\x944\xe9\xcd4Nw\xd0i%\x90d\xbf\x17\'\xbaP\xe9\xd3\x0b\x81d,\xdf?\xd1\x19\xd4\xfa\xa2\xdb\xcd\x0e\xe8CR\x9f/m6u\x81Hn\xdb\xd3\x81\xf4<\xd0\xab\x7f\xbe]\xd5\xe8\xac\xf2%\x9b\x0c\x00\xe9E\x97l\xcb\xde\x02\xd2\x95\x07\xea\xed\xa0\x10H&5\xc7S\x8f\x83$\xfb=\xb3\x99:\xa0\xd2C\xf6x\x9c\x00\x00\xf4\xf5\x02\x80[\x08\xd4O\xfc\xbd\x9f,\n>1\x9f\xd2\xea\x97\x84nu\x08\xbfT4e\x1fd\xc90\xf9\x1fl\xb5\xf1\xf7\xc6\x1d2\xa1\x1d=y\xfd;\x1f\xc2\xdc\x00\xc7\x051e\xb6\xe9\xf2v\xf0\xf6\xcf\xfd\xee\x93;*k\x82-\x1d\xaaseT\xe5\xa1nI\n\x15\x86\x85G\xb5\x9b\x95\xe9\xf53/\x90\xaa\xbc1\x9d\xf6i\xb1n\xd1\xab\xbf\x9dnS\xa5xl\\\xd7\xd5\xa2_J;\xf2S\xaf\x8b\x8b\x04\xb1\x88~\xa5\xaa\xd7\xd7\xe9^\x0f\x86j:\xfd\xde\xb8\xaf=\x9ej\x1c\xbe\xf5u\x07\x90\x99|\x028_\xe5[\x00\xd8\x13\x17\x00\xfc\xce\xf9\xe1u\x07\xf6\xe9\xf2\x02@\xba\xf3\x9b\xbb\xf5\xc5:\xf1\xc9@~\xce\xee\xa6\x99\xd7\x1d\xd8\xbb\x0b}\x02\x00\x00|+\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83\xf2\x01\xe0\xe5\xe5\xe5\xf5\xf5\xd5\xa7\x01\x00\x06\xe0\x03\xc0\x97/_L\x0c0\xcf\x01\x00\x80A\xf8\x00\x00\x00\x18\r\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\x04\x00\x00\x18\xd4\xe6o\x01\x00C\xe2\t\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06\xb5\xe1+\x80\x00`L\x1b\xbe\x04\x14\x00\xc6\xb4\xf1\xff\x02\x00\x06C\x00\x00\x80A\x11\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\xb5\x03\xc0\xd3\xfb\xcd\xe6\x87\xf0\xf3\xfe\xc9\xa7^\xbc\xa7\xed\x0f\x9b\x9b\x0f\x1f\xfd\xde\xb1}|\xb8\xd9ln\x1e\x967\xff\xb4U\xb9\x7f\xde\xba\x97\xa3\xd9\xff\x8f\x1fn\xf6x^Y\xbbg\xe0\xdc\xfas\x18\xbd\xb3\\\x9b\x0e\xac\xd0\n\x00\xb2\xd6l\xaff\xd5\xdf\xbb\xa7\xed\xce\x83\xf3\xf1a\xbbx\xd2\x9axQ\xb7\xf3\xf3\xf6\xdb\x17\xfa\xa7\xf7\x93\xfdo\xb6{B\xe7\xd6\x9f\x83\xe9\x9d\xe8\xdat`\xb9"\x00||\xf8Q\xdd\xfb\xcbO\xbc\xc6\xd4\xa1\x1f\xe3*&\xf7\xd4\x92\xf2\xfe)<4\xdc<|\xf6\xc7jO\xdb\x8d\xdc\x03?\xc9\xad\xb0\xa5\xeea\xcc\xe5\xec\x13\x8b\xbb\xe4x\xc0\x17\x0cGme\xce\x82[!s\x8f\xec;\xaf\x1eh|\xe2\xfb\xa7pt\xaa\xf3\x96j\xd4\xd230\x1e\xdb>\xd9>\xfb^\xa5"\x92.\x01\xc0\r\xc3v+\xe7\xe5\xf3\xe65\t\x93\xa91\xbd\xeb\x00\xd0\x7f2H\x8fq\xef\xb7[\xff\x92\x85\xd7+\xfcl\x7f\xb6Y\x95\xa2]W\x89T\xee\x1b\n\x07??\xdc\x84JR\xd36\xcf\xf6C<\xa4k\x8a\xd7\xcf\xcd\xc3\xcf\x92!\x94R]J\xd7U\x92\xf5\xc7\x8e\xdc\xf6!^*\xe1\x88K\xb7;n8\xed\xd8\xdb\xd4\xb9q\xd6\\\x81C_\x9f\xe9\xc0\xd6\xf4M\x1f\xda\xd7C\x80\xeb\xd2\xd4\x99\x02\xce\xc2\'\x00;K\xc3\xd2i\x17\x85\x94!,4\x92"+\xe9\xe4[Fj\xaa\xba\xbd\xb0\xfd\xf1\xe9)\\\xcb*UoK\xd1x\xc1g\xd7\xbe9\xd2\x9e\t%\xe9j\xde=I\xf9\xf1fk\x17#\xe9|k\r*4\x9f\x00T\x17\xcc\xf4\xbb\xb9\xf1w\xfa\xb2\x1dj\xb4\xd3\xd2\xef\xc9\xb9H-\x92fk++5\x07\x1a\xad4\x02\x80\xd3\n\x0c1\xa58\xaf\xc9\'\x80V\xbbn\xadw5|~xp1\xe3\xf3\xd3S\x08\x96f\x0cS \xd1\x17\x8f\xea\x83\xca\x93\xbd\x11\xf7\xf4^\x05]S\xb6\x1c\xff\xaa?a\xe4\xdcvz\xd9\xf5\x00\xa6\x07\xad\xd9q.I\x81X\xbf\xec\x85\xed}]\x9f\xea\x80tJ\xe5\xb2\t\xd9~\xb0C:\x01\x00\x8b,\x0b\x00e\x8a\xcc\xe18\xe7m\x00Xz\xb5\xe9\xc9#\xd2\x84\x94\xf9\x13\xa5D}\x85\xa7\xbd,\xb3\xb5\xa8\x03\x9d\x00\x10\x9ahD\xbe\x86\xd6\x1a\x92\xf73N\xcc\xf2-\x9f\x98-l\x98\x9c\xae\xb2\xb2\xd2r\x9c\xbc\xe5\x01\xc0T\x9d\x1e\xe6\xb2\xaa&\x03@\xab\xdd\xcf\x0f.@\xe6\xb2\x87\t\x1d\x00\xd2v*\xf8\x14\x1eA\xac\xd4\xdb\xac\x12\xfbS\xb4^\xf5\xa7\xbd\xd0\xf7\xd2g\xc7\xb9T\xb6\x97\xf2g\x97\\J\xd4\xaf{\xda\xcb2[\xb1V\xb7:;e_Z\xa3/\xd6\xa6\x03\x0b\xed)\x00L\xde\xf5k\xf9\x8c\x91}[o\\2-=\xebt\xf64\xb1\xcb\x95u\xa1v\x00\x88)\xfb\n\x00q\xf7\x94\x01@1\xb7\xf0K\x9f\x00Z\xed6\x02\x80\x89.\xd9\x9d\xfb\xba\x00\x90\xd2?>\xbc\xcf\x06\xa8R\xf5G\x0f\xd4A\x02@\xf6B\x86\xfc\x87\xb9>\xf3Z\x8d\xb5\x0b}/\x1dXhOo\x01\xad\x08\x00\xd9[\xa2a*\xe9\x89$Yb\xed\xc5\x81\xb8S\xcd\x9dE\xf6\x14\x00B\xcb\xa6\x13\xa1\xa7\xba\x9f\x92\xec\xf7\xccf\xaaP\xa5\x87\xec\xf1x\xb90e\x05\x93\xc5\x01 {k\xc5\x04\x00u\xd6\xe9\x90\xbc\xb7S\xb4\xd2j\xb7\x11\x00\xf4\x82\x9e\xdd\rt\x02@\xd6\x1f3\xe6\xb1\xb7\x1fg>\xbfT\xf5G\x0fT\x1e\x00\xc2\x0b\xa0/\xb1\xd9q.\x1d\xfa\xfa\xd4\xf9\xab\x93\xeb\x15\xda!\xbd\xf1x\x01\xd4\x8a\x00P=\x92\xa7y\xdeyKA\x16M\x9f>9\x93=\x99\x00\x0ff\x06y\xe9\xfa\x95i\xe5\xf8\x0c\xa1\ru`\xbb\xd5\xf7U\xe9\x80\x98\xbd\xdc\xf5\xa9\xf9\xc5(\xfc\xee\xd7\xc6\x80\xf8[M}\xaf\xda\xe4\xe6W\xd9\xa8\xea\xce\xd6\x9cA\xa8$e\xb6\xe9f\xe7f\xfb\xe7~\xf7\xc9\x1d\x95A\xb0\xa5\x8b\xea\xd4\xae\x1e|\xf7\xe3\x0e\xf6\xd2m`\xab\x12\xbdx\xa6\xe5\xea/\xa6\xdb\xd5\x0b}H\xbcy\xf8 \xdbr($\xcavh%\\\x15i\xfco\xdeouD\x99\xeaj\xd1\x9f0\xc6\x92\x12\x066\\B\xe1\x98I\xf0\xbf\x8c\xfd\x1f)w\x7f\x9c\x0b\x87\xbe>\x9b\x89A\x16\x1d\x94\xb5\xe9nh&\xce\x12\xf0ZO\x00\x87\xd4\xbbf\x17\xf9\xa6\xc2\xc7\xb4\xec\x1d\x80if\x16\x9fd\n\x1f\xa1\xdd\xe97\xac\n\xc7\x1d\x87\x13^\x9f\xbd\x13]\x9b\x0e,w\xd4\x00\xa0\xef\xa2\x96O\x94\xddJ\x9d\x8a\x99\x96\xfb\xea\xed\xa9\xe2\xdd\x81\xdaMw\xfa\xb3\xcfX\xb9\xa3\x8d\xc3I\xaf\xcf\xdeY\xaeM\x07V8\xf6\x13\x00\x00\xe0L\x10\x000\x9a\xfc}\xf8\x847T0\x1c\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x06\x0c\x00\xf6s:#}\x82\xe2Z?/r\xdc\xf3\xe2\xd38\xb8Bc>\x01\xec\xe3s\xfagc\xe6\x8f[\xcf\xfe\xe3\xe23_O\xdds\xf4\xf3\xea5x\xf6\x03\x0ct\x1d;\x00\xb8O`\xc8=\x93\xff,\xc6\xfe\xe7\x8e\xbd\xc3\xb7\xe4o6\xe3\xedY\xfa\xecG\xf8Z\xe6\x94(\x9d\xf0\xc5fn\xe7\xfa\xfdO\xf5\x17u\xc4\x03\xe9k\xa2m\x92+\xe9\x9aU%\xe6\xebQ_#\xac2[\xf5h\x9a\x1cy\x17O\xf3u\xdcF\xfa;\x80\x05_O\xed2\xcb\xdf\x8b\xf9\xbf..\xcf\xec\x14\xe7\xc5C\x00\xae\xcd)\x9e\x00\xf4\x9a\xf7\xf1\xe1\xa1Z\xb3\x82\xdf\xff\xf2\xfd\xd7\x9f\xbe\xab~\xbe\xff\xe3o}\x86\x06\xa9;[\x18B3\xe9[Sl\xf3i\xc6\x9aLnGr\xd7\x0bhC\xab\xff\xd9\x1a\x10\xab\xcc6\xa5\x0f\xe1k\xa2\xe5@jK=\x90\xf4\xea\xd1\x07\xa4\xfd,\xd7D\xafM\xde\xec\xa8\x9cd6@a{\x0f_w<\xf9z\xa9\xbf\xfe]\xfa\xf5\xd4\xee\xcb$\\\xce\xf85\xd4\xde1\xcf+\x92WP\xef\x07\xbdt\xe0\xdc\x9d&\x00\x1c\xec\r\x98N\xd5er6\xcd\xddD7\x96v\xaa\xd1\x88,"9\xb7\xbc\xe4\r\xe9\x85\xa2\x1d\x00z\xf5\x18\xa6\xb0O*\xe2\xd4d\x000\x15\x16\x99{\x85\xb3\xa6S\xa2\xee\x7f\xda\x9b\xe8gO\xe7\xbb\xa4L]\xfd\x00P}\t]t\x9a\xf3*[\tz\xe9\xc0\x99;\xe7\x00\xb0\xc3\x13\xc0N\x01\xc0.\xadrw\xbep\x0e7\x1a\xe9\x9dR\xde\x90\xdem\x07\x80^=\xb9\xfc\x8ese\x00\xc8:\x14\n\xf7j,\x07j\xb2\x9f\x8b_/sk\xbf\xec\t`M\x008\xdcy%\x04\x00\\\x99+{\x02(f\xbc,\xeda!H3TRc&3w\xfd\xe4\xcd\x92\xa7\xb4\xfa\x9f\xb7\x9b\xe8\x95\xa6h7lJ\x0fb\xf2\x92z$\x93Zo\xd2!i\xa0X\x88\xf2\xacEc\xb2\xeb\x8e\xea\xea\xd3\x88\xd8\x9d\xec@\xdc\xe9\xf5\xb3g\x97\xaf\xa7\x9e\n\x00\'9\xaf\xde\xc1\xb5\x83\x01\x9c\x8b#\x07\x003U\xfc\xa3\xb5\x93M\xe2=\x91\x89\x1e\xa4\xfau\xcb\xfek\x99\xfd/c%\xc1d\x0b\x19&\xa7\xf2T\xffu\xbb\xea\x88J\xd6_\x13\x9d\xd2\x8b_B\xb6\xeb\xe9Tn\xa5N\xe5\xe9\x96)\x98w\xf24_\xc7\xbd\xf2\xeb\xa9\xfb_C\x1d\x9c\xe2\xbct\xd4\xd0z\xe9\xc0\xb9;\xc5\x13\xc0\xb8\x0e\xf9\xec\xd3c\xc2\x83Z\xc4\xbei\xad:\xab\x85\xee\xe8\xe7\x957\x98\xf4\xd2\x81\xf3G\x008\x92t\x9b~\xf4E4\xaeo\xfanxy\x1fv+u\x04\xc7=\xaf^\x94\xf8\xa6\xd0\x03\x9c\x16\x01\x00\x00\x06E\x00\xa8\xe5o\x02\'<\xe8\x03\xb8*\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\xd7\x19\x00>\x1e\xf8O3\xd3g:G\xfa\xd5p\xfe\x81G>\xfe\x08\\<\x9e\x00vp\x9a\xb5/}\x93\xcd2k\xf3\xcf\xa8\xfe\xde\x89?\x80\x02.\xdd\xb1\x03\x80\xfb\x88\xa5\xac\x9f\xfe\xc3\x963kH7\xbf\xba\t\xcfV\xe3\xf0\x19\xcez\x89\x0eGL\x1d\xf1\xfb\xf4\xb3\xe4%\x7f\x10\xa4\xef\xfd\x85*\xa2*J\'\xe5\x12%\x97?<\xbff\xb6\xfa\xa9\xea\xb6R-\xedq\xe8\xe4\xb7\xc9n\xdb\x95\xd3g\xdcj71G\xab\xae\xf3\x10\x00\\\xb6S<\x01\xe8\xb5g\xea\xff\x07\x104\xf3w\xbe\xe7\xdd\xab\x97&\x95"\xf5\x85\x9d,\xa3\xa9\xa8,\xd6\xd4X\xf8\xb2\xa2\xa6\x01\x9da\xd5\xf9v\xfai\xb4\xef\xe8\xfb\xe3\xd0\xce\xafS\xf57S\xf4\xdb\xb5LZ][q\x9e\x00.\xcci\x02\xc0\xbao\xc4i\xe77\xcb]R.N\x8d%\xda-\xc3N\xcc\x9eUb\xb5\x16\xcdR]{\xb9\xd8f]^w\xbe\xcd~\x8a\xce[:\xddqX\x17\x00\xfa\xedZEp\xf1\xda\xa9\x00.\xc4\x85\x06\x80\xfc\xde\xb3^\xea\x1a\x01@I\xa5\xd7v\xc59h\x00P\xe6\xcer:G+\x7f\x9e\xda\xebX^\xabE\x00\x00\xae\xd0Y\x05\x00\xb3\xf0\xb4n?\x1b\xf9\xf5\x12,\xb7\xc0e\x99j\x89\xce\x12L;\xa1@c\xad\x9b\xd7\x08/yR\xde\xe35\x01\xa0\xd7O#\x1d\x92qr\x07t\xf6r\x1cZ\xf9u\xaa\xe4\x8f\xa5\'\xda\xb5\x1aI6Q\x95\x02pi\x8e\x1c\x00d)\xd2\xf2E\xc5\x1d\xd5i\xfd\xfc\xb2|9\xfa{\xde\xcb\xfc\xb1D\xca.\xb2f\'\x0e\xd5\xf2\xcc\xed\x0e\x19!y\xfa|\x1b\xa6:\x93*S\xe9\xa9@\xf1}\xf7\x9d\xfc\xa9@\xf6\xff!\x98j\xd72\x19\xaa\xd4,j\x00\xb88\xa7x\x02\xc0%2\xe1$\x8f\x00U\x02\x80\x0bC\x00\xc0R\xf9\r?\xb7\xff\xc0\xc5#\x00\x00\xc0\xa0\x08\x00\xb5\xfc\xfd\xf0d_ox\x1c\xba~\x00X\x84\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000\xa8\x13\x06\x00\xfb1\xf5\x81>I\xb2\xf6|\x1b\xf9M\xd2A\x06\xcc\xfeVb\xdf\xbf\x82\xd8\xdb\xeb\xbb\x8f\xcf\x1b\xb5\xfe\x8ca\xdf\x96}J\x8aOO\xe1\x8c\x9c\xf6\t`\xd1\xdf\xc8\xb6\xbf\xd2\xe0"\xad\xf9\x9b`\xb16\x7ff\xdd\xb8\x1dd\x94\xbf\xa9\xff\x9e\x89#\x17\xf1\xfaW\xfd\xecu\xfcRN\x08#8~\x00H\x9f\x81\xd9>\xa9\x05\xc2\xde/:\xea\x0e\xa9\xfc\xc0L\x9a9\xed\xfc{\xe3\x1a\x96\x9a}\x17b\xcb\xaaK\xba\xe1n\x7f:\xe7\xdb\xd5\xc9\x1f\x92\xeb\x93M-\xcb\xdf\x02\xbb\xe3\xaa\x93\xd6\xfc\x8a#\x01 \x96\xd2\xd9UU\xdft\xbe\xedz\\\xaa$\xf8\xe3eOMr\xdd\x9b\x89\xfc\x05\x9f\xcb\xca\xfb\xa9\x0e\xe5_\x7f\xad\x8a\x84\xcam\xd2\xf6!\x9er\xa3Q\x93\xa5J\xe5!\x00\xe7\xee\xc8\x01\xc0,\x1b\xf1\xda\xb7KH\xda[\xf9\xb5\xc6\xd3_\x07\x9d\xf9\xfd/\xdf\x7f\xfd\xe9\xbb\xea\xe7\xfb?\xfe\xd6g\xe8pk\x9c\xeba\xf8\x1a\xe7l\xee\x9a\x86g\xfa\xdf?\xdf\xb6\xb9\xfc\xd5\xd2!\x99\xe2\xc9\x9b\x86U\x81\xb5O\x00\xa9\xacje_\xe7\xdb\xad\xc7\xb0\x19}J\xf9u\xd9\xe6Xu\x16S\xf9\xfb\x8a\xe0\xab:$\xf5\x85\x9d\xack\xe6@\xdc\x91\xf1\t=\xa9^\x05\x9b\xb5\x1em]^\xeb\xa5\x03\xc7v\xdc\x00P\xde\x01\xeb\x99$3,\xd2\x93\xa9\xb3\x90u\xf3\xefM\xe3~=k\xd4\x8a-\xb7\xfa3u\xbe-\xb3\xf9\xcb\x84F\x17\xa3\xb5\x01 \xe5N\xb5\xee\xeb|\'\xea\x99;\t\x9d\xd3\x99\xca\xdfW\x96\x92e?P\'\x95\xb7\xa6G"\x1dit\xa0\xd5\xcf^j?\x1d8\xb23\t\x00\xf9=Q>\r[\x0b\xd9T\xfe\xca\xeeO\x00\xd5<o$Y\x9d\xfet\xcf\xb7c6\xff\xb1\x03\xc0\xbe\xcew\xaa\x9f\x93\x07\x0f\x17\x00\x94t6\xe5\x98\xa5B\xed\xf1\x89\x08\x00\xb8H\xc7\x7f\x0bH\xcf\xa3\xf8\xe8\xad\x1763;\xb2\xe9\x91\x8eI\x01wd*\xff\xde\xb4\x96\x8c|\xe5\x8bz\xfd\xe9\x9do\xcf\\~\xdd\x8e\x95\xf7GJ\xc4\xf2\xadq\xeb\xeb,py\xfd\xd1\xea\xf3\xed\xd4cM,\xcdy\x85^7\xbf4\xd8\xbd\x16\xf2R\xd9@\xaaF\xf2\x01Vef\x02@\xab\x9f\x92\xd8<\xe9^:plG\xff%\xb0\x9b\xa4\x8e\xfb\xb5\x9a\x9b\x0b\xb2\x8c8\xcb\xbe\xd6x"\xff\x1e\xe8^\n]yjY\x84#\xbd\xfe\xf4\xce\xb7\xa7\x9d\xbf\xec\x8f\xee\x91\xeeO6\x08\xcdqk\nUH\xbeP*vs_\xe7\xdb\xaa\xa7<\xaf\xba\xa3\xa6\x94J\x9c\xce\xef\x8e\xd6uXe\x00p\x158\xbaHv\xc4\x1f\x08i\xb2[\x8d\x8f\x93\xf7\xd3\xa9\xc2\xb5\xd7K\x07\x8e\xed\xe8\x01\x00X\xc5,\xb8\x9d%}\x9dC\xaf\xbaU?{\x1d\xdf\xd7\t\x01\xdf\x8e\x00\x80s\xf7\rKw\xb8]7\x0e\x7f\xd3\x9d\xf7\x93\xdb\x7f\\\x00\x02\x00\x00\x0c\x8a\x00p|\xf9\xfb\xcf\xc9\xa1\xdf\x188U\xbb\x00\xce\x14\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\'\t\x00O\xdb\x1f67\x1f\x1a\x1f\x85xz\xbf\xd9\xfc\x10~\xde/|k\xda~\xd2\x83OV\x00\xc0J\xe7\xf4\x04\xf0\xf3v\xf3\xc3n\xbf\x90\xec\xfem\xa8V\xfe\x99?\x00\x8c\xed\xd8\x01\xe0\xe3\x87\x9b\xd6\r\xfe\xc7\x87\x1f\xd5\xbd\xbf\xfc\xcc.\xd6\xe93-\x07\xfbZiw\x8c\xb0\x01\xe0:\x9d\xe6\t@\xde\xea\xa9\xdf\xe1Y\xf1\x04`\x96\xe6\xb8\\\xe7o\x01\xed\xf3k\xa5\t\x00\x00\xae\xd9e\x06\x80\xf2-\x1f\xfd\xd7\x95\xd9\xcd\xfe|\x00\xe8\xe7\x07\x80\xebve\x01@?\x19\x94K~+\x00L\xe5\x07\x80\xebv\xb9o\x01\xa5\x9c\xf2N\x8d_\xc6\xcbG\x81<\x00\x84cR\xc0\x1d\x99\xca\xef\xf2\xf1T\x00\xe0Z\x1d?\x00\xc8g@\xc3ozo\x1e>\xd7\x89\xf6\xe7\xc7t_\xde\xe6\x16g\xe7P_+M\x00\x00p\xcdN\xf3\x04\x00\x0089\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83\xba\xa2\x00\xf0\xf9\xe1\xc6\xfe\r\xc1\xf6g\x9f\xb0w\xfe\x9b\xecf\xffF\x01\x00.\xc1\x95=\x01\xc8\x1f\x94\x1d.\x00\x18\x12\x03\x08\x00\x00\xae\xc2U\x06\x80\xf8\xe5\xd2\xd5_\x1a\xbf\x7f\n\xff\xcf\x99\xe6\x1f!\xa7?\xfa\r\xd9\xec\x8fZ\xf1c\x00p\x19\x0e\x1al\x00\xe0\xa0\xae0\x00\xa4\xc5]\xbe\\(.\xf4qM\x97U^\xd6\xf1\xf7O\xee]\xa3\xb8\x88\xdbwxR\xfe@\xc2I\xfc\xff\x97\x85\x00\x90%\x02\xc0%\xba\xee\xb7\x80\xb2e\xda\x06\x80\xec\x8b}\xec\x8a\xef\xa2B\xfa\xf1\xc5%x\xa4\xc4"\x00<}\xb8\xe1\xde\x1f\xc0\xa5\xbb\xf2\xdf\x01\xc8\xa2\x1f\xbevTo;6\x00\xb4\xbe\xeb-{2\xa8\x9e\x00|T\xe0K\xe2\x00\\\xb6k|\x0b(\xbee_\xbf\x05T|\x07\xb5\xfb\xe0PL\xb4w\xfd\xb2\xee\xeb/\xa6\xb6\x89\xcd\xb7\x80Z\xef\x17\x01\xc0\xc5\xb8\xa2\x00\x10?\x06\xfa\xc1o\xf8\xd5\xdcQo\xe9\xe4\xef\xdd\xeb_\x02\xa7\xe0\x11~a`\xc2\xc3\x83]\xeb%N\xf8\xdb\x7f\x97\'U\xc8\xa3\x00\x80\x8bteO\x00\x00\x80\xa5\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa06\xaf\xaf\xaf~\x13\x000\x92\xcd\xcb\xcb\xcb/\x00\x80\xf1l\xbe\x02\x00\x86D\x00\x00\x80A\x11\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\x11\x00\x00`P\x04\x00\x00\x18\x14\x01\x00\x00\x06E\x00\x00\x80A\x1d/\x00\xfc\xf8\xbf\xff\xed?\xfe\xcf\xff\xfb\'\xff\xfdd?\xff\n\x9c\xab\xdf\xfd\xeew\xbf\xfe\xfa\xab\x9f*\xc0\xb1\x1c/\x00\x9cv\xf57?~\xaa\x01g\xc9\xc4\x00?U\x80c9^\x00(\x96\xe3\xe3\xff\xf8y\x06\x9c+?U\x80c!\x00\x00\xe7\xc2O\x15\xe0X\x08\x00\xc0\xb9\xf0S\x058\x96\xc9\x00\xf0\xe9\xf1\xed\xe6\xee\xd9\xef\x18\xb2o\xbd}\xfc\xe4\x93\x9e\xef\x8a\x84\xb2LT,\xc7\xc7\xff\xf1\x93\x0c8W~\xaa\x14\x8a)\x15g\xa1N\xf4\xf3\xd0\xa8&_c\x16\xa7\xe9\xda\x98\xafEJ\xb3\xe6\xd4\x87f\xaa\xaa\xdfq\x95\xe8\xe4\xb2\xdd~\xd9$\x95Q\xed{\xba\xae\xb6\xb2\xc5\xa0y\x82\x13\xe3i\xcc\x8c\xc9|_\xba\x9dI\xb5\x14\xaf\x91\x13\x8a\xc4\xe2Y=f\xa79z\xbe|\xb3\xbd~\x00\xf0\'\x99J\x99\x04\xbfc\xb6\\C\xa1\xc5\x98\xa02\x95\x8a\xe5\xf8\xf8?~\x92\x01\xe7\xcaO\x15\xad\x9c\x86i\xaa\xc9\xb4\x8e\xd30dP\x9bVY<\xcdYQ\x1f-R\xda5\xa7>\xd8\xd4j\xea\xab\xe3^:f\x15\xadL\x97\r\xa4\xa9\xac\xafA\xbfHR\xb5\xe85O\xb0\x99\x18\xb5\x8fJ\x03\xa9\xf4t\x7fz\x9d\xb1GR}i\\\xfb5\xeb\xfe\x99\xed~\xbb\xa9\xe6\\;\x00\xd8\x1e\xbe}|V\xb57k\x08i\xa1\xe9\xa9.\x14\xcb\xf1\xf1\x7f\xfc$\x03\xce\x95\x9f*Ac\x1af3\xac5%\xd5\x8a\xd0\x9a\xc5\xa9P}\xb4\x9d?\x8a5\xe7\xcd\xaa\xfaZ\xa5\x1cu\xb0\xd5J\xab\xac:\x11!\'~w\xd7\xe8\x99)\xdbZs\xa4\xb8\xcf\xdch\xb1\xa8\xdc\x99N\x9c=\x9a\xbd.\xdde\xb0u\xfaQg\x1c\xea\x9a}\xbb\xb62aK\xc5\xd21Y\xd5\xd6\xaaZ,~\x0b\xc8\xf6\xe3\xd1\xd7\x1cz\x14:\xe7\xfa\xa5\xb3\xd7\x8a\xe5\xf8\xf8?~\x92\x01\xe7\xcaO\x95B6\xaf\xdcT\x93-I\x0e\x131j\xcc\xc1<\xa9\\\x08\xea\x02\x8d*D\'9\xf4\xc7\x1c\xae\xd7\x87\xa8^~tu\xd3e\x85\xcd\xd1Z`\xaa$IhW\xd3(\x9di\x1e\x9f.\x94\x8e\x9a\xad\xd4bz\x8d\xbaz\x8d\xf5\xd7XK\x8d\xb6+\xae\xea\tc\x9c\xc6Z7R\xbf\x02\xce\x9a\x00\x10\x03\x8a\xd9\x0e}2\xf5\x86\xde\xba&TB\xaeX\x8e\x8f\xff\xe3\'\x19p\xae\xfcT)\xe8i(\xfc\x14+\xe7\x98\x9d\xa1\x8d\x99\x97\x15WS\xd7)+\xef\xa5\xb4j\xb6\x07|\xaa\xcd\xe3\x8b\x99\xed"o\xbd\xfc\xe8V\xa6\xcb\xa64]\xc61\xf5\xaa\xdc20U\xe1\xa8.\x1d\xd9\x0e\x94e\x9b\x89QyT\xdav\xb5\xdb#\xfdn8\xcd\xce\xd8\x92\xd58\xb4j\x8e\xc5S=\xb1@>&\x81I\xad\xda\x13\xeb\x9e\x00B\xb5\x8d6\xdc\xf1\x90\xab\x91\xa1X\x8e\x8f\xff\xe3\'\x19p\xae\xfcT)\x14\xd30\xce\xac\xb42h\xd5\xd4+\x8a\x17\xf3R\x1fu\xea\x14\xaf\xa8Y\x9aO\xfbY\xcdU\x1fLBQe\xb7W\xad\xfe\xfb\x84\xaagU^\x97\xa7\xbdnW\xa5+\x8d\xea:\x89\x91:\x9aZ~\xaeF\xb9\xd2\xec\x8cIL\xe5&k\x8e\xc5\xf5F,\x1b\xf2\xebQ0\xd55O~q\x00054;\xe7\xf9\xfaC3\xba;^\xb1\x1c\x1f\xff\xc7O2\xe0\\\xf9\xa9R\xd0\xd30\x9by\xf54\x14a\x0e\x06E\xf1\xecX1\xc7\xad:%H\xa5%O\x91ir}\x98iw\xaa\xacm*\x13\x0fW\xcd(u\x0f\xfb\xe7\x15\xd5\xdd4\x9a\x89Q\xeb\xe8t\t\xab\xdd\x99\xe95\xd6\x085\xc7\xe2q\xa3\xd9\xa6\xaa\xa3\xd7\xa7\xe5\x01@Ua\xd2\xf3\xbe\xc5\x84\xb0\xa1Z\x0e\x8a\xe5\xf8\xf8?~\x92\x01\xe7\xcaO\x95\x82\x9e\x86\xb2\xad\xe6\xb4K\xcff[5\xf5T\xf14\x85#]\xb9\xa3S\x9a5K\x86\xaa\x1e]\xb9\xc9\x90w\xa1\xd1p\xde\xeeT\xd9$/3\x99\xb5\xa1(\xed4O\xb0\x99\x18\xb5\x8f\xa6\xd4f;\xa5N&SK5\x0e\xad\x9a\xe3V\xd8H\x05S\xf6l;e\xc8\xad\x08\x00\xb6\x12\'\xaf*\xf5\xd5\xf0yRBP,\xc7\xc7\xff\xf1\x93\x0c8W~\xaa\x14\x8ai\x18g\xa1\x9ad\x92\xc5\xabf^*\x9eMT\xaf\xa8\xdc\xc8S\xea\x9aU\x8a\x17rw\xd6\x07\xa3^~\xcav\xab\xb2u\xc7\xca$S\xa4^f\xfati\xb5-\x9b\xde\xe4x\xce\x15Ig\x10\xd3T\x91\x92>\x94ek\x8d\xe1T\xcd\xae/\xff\xe9\xae^\x82E\xaa\xc4$\xaa\x1a\x93\xc9\x00\xb0W\xc5r|\xfc\x1f?\xc9\x80s\xe5\xa7\xca\xf5\xe9-?\xd7\xee\xf9\xee\\N\x9b\x00@\x00\xc0\xb9\xf3S\xe5\xfa\xb8\x9bRu\xbb<\x86O\x8f\x8f\xe7\xb0\xfe\xbb\xa7\x84S\x07\x00\xbe\x0e\x1a\x98\xc0\xd7A\xe3\xf8\x8e\x17\x00\xfe\xeb\xdf\xff\x9f?\xf9\xcf\xff\xf4\x1f~\xf8\xe5T?~\x9e\x01\xe7\x87\xff!\x0cN\xe2x\x01\x00\x00pV\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00\x83"\x00\x00\xc0\xa0\x08\x00\x000(\x02\x00\x00\x0c\x8a\x00\x00\x00C\xfa\xfa\xf5\xff\x03\xf8\xb2\xce=0\xa5\xc0s\x00\x00\x00\x00IEND\xaeB`\x82',
     {'url': 'https://skeptric.com/searching-100b-pages-cdx',
      'timestamp': datetime.datetime(2021, 11, 26, 11, 28, 39)},
     {'title': 'Searching 100 Billion Webpages Pages With Capture Index',
      'date': '11 June 2020',
      'url': 'https://skeptric.com/searching-100b-pages-cdx/',
      'timestamp': datetime.datetime(2021, 11, 26, 11, 28, 39)},
     {'title': 'Fast Web Dataset Extraction Worfklow',
      'date': '21 November 2021',
      'url': 'https://skeptric.com/fast-web-data-workflow/',
      'timestamp': datetime.datetime(2021, 11, 26, 11, 28, 39)},
     {'title': 'Unique Key for Web Captures',
      'date': '19 November 2021',
      'url': 'https://skeptric.com/key-web-captures/',
      'timestamp': datetime.datetime(2021, 11, 26, 11, 28, 40)},
     {'title': 'Hugo Readdir Error with Emacs',
      'date': '22 November 2021',
      'url': 'https://skeptric.com/emacs-tempfile-hugo/',
      'timestamp': datetime.datetime(2021, 11, 26, 11, 28, 40)}]

{% endraw %}